@@ -1,9 +1,9 @@
 #include "gallery.h"
 #include <QFileSystemWatcher>
 
-#include <MauiKit/fileloader.h>
-#include <MauiKit/fmstatic.h>
-#include <MauiKit/tagging.h>
+#include <MauiKit/FileBrowsing/fileloader.h>
+#include <MauiKit/FileBrowsing/fmstatic.h>
+#include <MauiKit/FileBrowsing/tagging.h>
 
 static FMH::MODEL picInfo(const QUrl &url)
 {
@@ -11,7 +11,7 @@ static FMH::MODEL picInfo(const QUrl &url)
     return FMH::MODEL{{FMH::MODEL_KEY::URL, url.toString()},
                       {FMH::MODEL_KEY::TITLE, info.baseName()},
                       {FMH::MODEL_KEY::SIZE, QString::number(info.size())},
-                      {FMH::MODEL_KEY::SOURCE, FMH::fileDir(url)},
+                      {FMH::MODEL_KEY::SOURCE, FMStatic::fileDir(url)},
                       {FMH::MODEL_KEY::DATE, info.birthTime().toString(Qt::TextDate)},
                       {FMH::MODEL_KEY::MODIFIED, info.lastModified().toString(Qt::TextDate)},
                       {FMH::MODEL_KEY::FORMAT, info.suffix()}};
@@ -118,14 +118,14 @@ QStringList Gallery::files() const
 void Gallery::scan(const QList<QUrl> &urls, const bool &recursive, const int &limit)
 {
     this->scanTags(extractTags(urls), limit);
-    m_fileLoader->requestPath(urls, recursive, FMH::FILTER_LIST[FMH::FILTER_TYPE::IMAGE], QDir::Files, limit);
+    m_fileLoader->requestPath(urls, recursive, FMStatic::FILTER_LIST[FMStatic::FILTER_TYPE::IMAGE], QDir::Files, limit);
 }
 
 void Gallery::scanTags(const QList<QUrl> &urls, const int &limit)
 {
     FMH::MODEL_LIST res;
     for (const auto &tagUrl : urls) {
-        const auto urls = FMStatic::getTagUrls(tagUrl.toString().replace("tags:///", ""), {}, true, limit, "image");
+        const auto urls = Tagging::getInstance()->getTagUrls(tagUrl.toString().replace("tags:///", ""), {}, true, limit, "image");
         for (const auto &url : urls) {
             res << picInfo(url);
         }
@@ -154,7 +154,7 @@ QList<QUrl> Gallery::extractTags(const QList<QUrl> &urls)
 {
     QList<QUrl> res;
     return std::accumulate(urls.constBegin(), urls.constEnd(), res, [](QList<QUrl> &list, const QUrl &url) {
-        if (FMH::getPathType(url) == FMH::PATHTYPE_KEY::TAGS_PATH) {
+        if (FMStatic::getPathType(url) == FMStatic::PATHTYPE_KEY::TAGS_PATH) {
             list << url;
         }
 
@@ -243,6 +243,18 @@ void Gallery::setlimit(int limit)
     emit limitChanged(m_limit);
 }
 
+int Gallery::indexOfName(const QString &query)
+{
+    const auto it = std::find_if(this->items().constBegin(), this->items().constEnd(), [&](const FMH::MODEL &item) -> bool {
+            return item[FMH::MODEL_KEY::TITLE].startsWith(query, Qt::CaseInsensitive);
+        });
+
+        if (it != this->items().constEnd())
+            return this->mappedIndexFromSource(std::distance(this->items().constBegin(), it));
+        else
+            return -1;
+}
+
 void Gallery::componentComplete()
 {
     connect(this, &Gallery::urlsChanged, this, &Gallery::rescan);
