@@ -3,8 +3,8 @@
 
 #include <QObject>
 
-#include <MauiKit/fmh.h>
-#include <MauiKit/mauilist.h>
+#include <MauiKit/Core/fmh.h>
+#include <MauiKit/Core/mauilist.h>
 
 #define PIX_QUERY_MAX_LIMIT 20000
 
@@ -94,5 +94,7 @@ public slots:
 
     void setRecursive(bool recursive);
     void setlimit(int limit);
+
+    int indexOfName(const QString &query);
 };
 #endif // GALLERY_H
